/******************************************************************************
* 		                                         COPYRIGHT (c) MOTOROLA 2002   
* FILE NAME: basic.c                                                      
*                                                                           
* PURPOSE: I2C demo - master software      											 
*                                                                           
*******************************************************************************
*******************************************************************************  
**  THIS CODE IS ONLY INTENDED AS AN EXAMPLE FOR THE METROWERKS COMPILER AND **  
**      THE STAR12 EVB AND HAS ONLY BEEN GIVEN A MIMIMUM LEVEL OF TEST.      **  
**  IT IS PROVIDED 'AS SEEN' WITH NO GUARANTEES AND NO PROMISE OF SUPPORT.   **  
*******************************************************************************  
*******************************************************************************
*                                                                           
* DOCUMENTATION SOURCE: EKB Apps                                          
*                                                                           
* TARGET DEVICE: 68HC912DP256                                               
*                                                                                                                                                                                                                                                            
* COMPILER: Metrowerks                     VERSION: MOT v1.2                     
*                                                                           
* DESCRIPTION:                                                                                                                                
*                                                                         
* AUTHOR: Grant More       LOCATION: EKB      LAST EDIT DATE: 20/05/02
*                                                                         
* UPDATE HISTORY                                                         
* REV      AUTHOR       DATE       DESCRIPTION OF CHANGE                  
* ---      ------      ---------    ---------------------                 
* 1.0	   G.More	   20/05/02		Initial Coding                     
*
******************************************************************************/                                                                        
/*===========================================================================*/
/* Motorola reserves the right to make changes without further notice to any */
/* product herein to improve reliability, function, or design. Motorola does */
/* not assume any  liability arising  out  of the  application or use of any */
/* product,  circuit, or software described herein;  neither  does it convey */
/* any license under its patent rights  nor the  rights of others.  Motorola */
/* products are not designed, intended,  or authorized for use as components */
/* in  systems  intended  for  surgical  implant  into  the  body, or  other */
/* applications intended to support life, or  for any  other application  in */
/* which the failure of the Motorola product  could create a situation where */
/* personal injury or death may occur. Should Buyer purchase or use Motorola */
/* products for any such intended  or unauthorized  application, Buyer shall */
/* indemnify and  hold  Motorola  and its officers, employees, subsidiaries, */
/* affiliates,  and distributors harmless against all claims costs, damages, */
/* and expenses, and reasonable  attorney  fees arising  out of, directly or */
/* indirectly,  any claim of personal injury  or death  associated with such */
/* unintended or unauthorized use, even if such claim alleges that  Motorola */
/* was negligent regarding the  design  or manufacture of the part. Motorola */
/* and the Motorola logo* are registered trademarks of Motorola Ltd.         */
/*****************************************************************************/

/* include files */
#include "basic.h"

/* additional #defines */
#define SLAVE 0xF0
#define PACKETSIZE 8

/* Global variables */
tU08 TxPacket[PACKETSIZE];			/* global transmit packet */
tU08 *TxPacketpositionptr;			/* pointer to current location in transmit packet */ 
tU08 *TxPacketendptr;				/* (fixed) pointer to end of transmit packet */
tU08 TxBufferemptyflag;				/* global flag for transmit functionality */
tU08 RxPacket[PACKETSIZE];			/* global receive packet */
tU08 *RxPacketpositionptr;			/* pointer to current location in receive packet */ 
tU08 *RxPacketendptr;				/* (fixed) pointer to end of receive packet */
tU08 RxBufferfullflag = 0, MasterRxFlag = 0;	/* global flags for receive functionality */
tU08 TxCompleteflag = 0, RxCompleteflag = 0;	/* global flags for ISR functionality */

/******************************************************************************
Function Name	:	main
Engineer		:	G.More
Date			:	23/05/02
Parameters		:	NONE
Returns			:	NONE
Notes			:	Main program functionality
******************************************************************************/
void main(void) 
{									
	TxPacketpositionptr = &TxPacket[0];	/* point to first TxPacket element */
	TxPacketendptr = &TxPacket[(PACKETSIZE-1)]; /* point to last TxPacket element */
	TxBufferemptyflag = CLEAR;
	RxPacketpositionptr = &RxPacket[0];	/* point to first TxPacket element */
	RxPacketendptr = &RxPacket[(PACKETSIZE-1)]; /* point to last TxPacket element */
	RxBufferfullflag = CLEAR;
	
	EnableInterrupts;					/* enable interrupts */
	ConfigureI2CModule();				/* call initialisation function */
	
	TxPacket[0] = 0x01;
	TxPacket[1] = 0x02;
	TxPacket[2] = 0x03;
	TxPacket[3] = 0x04;
	TxPacket[4] = 0x05;
	TxPacket[5] = 0x06;
	TxPacket[6] = 0x07;
	TxPacket[7] = 0x08;	
	
	MasterTransmitPacket2Slave(SLAVE);		/* transmit initial packet to slave */
	
	while(FOREVER)							/* forever loop */
	{
		MasterReceivePacketFromSlave(SLAVE);	/* receive data from slave */
		TxPacket[0] = RxPacket[0] + 1;
		TxPacket[1] = RxPacket[1] + 1;
		TxPacket[2] = RxPacket[2] + 1;
		TxPacket[3] = RxPacket[3] + 1;
		TxPacket[4] = RxPacket[4] + 1;
		TxPacket[5] = RxPacket[5] + 1;	
		TxPacket[6] = RxPacket[6] + 1;
		TxPacket[7] = RxPacket[7] + 1;		
		MasterTransmitPacket2Slave(SLAVE);	/* transmit new packet to slave */		
	}
}

/******************************************************************************
Function Name	:	ConfigureI2CModule
Engineer		:	G.More
Date			:	23/05/02
Parameters		:	NONE
Returns			:	NONE
Notes			:	Procedure that configures and sets up I2C bus.
******************************************************************************/
void ConfigureI2CModule(void)
{
	Iic.ibfd.byte = 0x00; 			/* frequency divider register */
	Iic.ibad.byte = 0xA0;			/* slave address of this module */
	Iic.ibcr.byte = (IBEN|IBIE); 	/* enable Iic module */
}

/******************************************************************************
Function Name	:	MasterTransmitPacket2Slave
Engineer		:	G.More
Date			:	23/05/02
Parameters		:	tU08 slaveAddress
Returns			:	NONE
Notes			:	Procedure which sends data on the I2C bus
******************************************************************************/
void MasterTransmitPacket2Slave (tU08 slaveAddress)
{
	while(Iic.ibsr.bit.ibb == SET) 		/* while bus is busy */
	{									/* wait until bus is free */
	}

	Iic.ibcr.byte = (IBEN|IBIE|MSSL|TXRX);	/* grab bus - start condition initiated */
	
	Iic.ibdr.byte = slaveAddress;		/* address the slave */				
	
	while(TxBufferemptyflag == CLEAR)	/* wait while message is transmitted */
	{										
	}
	TxPacketpositionptr = &TxPacket[0];	/* point to first TxPacket element */
	TxBufferemptyflag = CLEAR;
}
	
/******************************************************************************
Function Name	:	MasterReceivePacketFromSlave
Engineer		:	G.More
Date			:	23/05/02
Parameters		:	tU08 slaveAddress
Returns			:	NONE
Notes			:	Procedure which sends data on the I2C bus
******************************************************************************/
void MasterReceivePacketFromSlave (tU08 slaveAddress)
{
	MasterRxFlag = SET;

	while(Iic.ibsr.bit.ibb == SET) 		/* while bus is busy */
	{									/* wait until bus is free */
	}

	Iic.ibcr.byte = (IBEN|IBIE|MSSL|TXRX);	/* grab bus - start condition initiated */
	
	Iic.ibdr.byte = (slaveAddress | 0x01);	/* address the slave, insruct slave to transmit */				
	
	while(RxBufferfullflag == CLEAR)		/* wait while message is being received */
	{									
	}
	
	RxPacketpositionptr = &RxPacket[0];	/* point to first TxPacket element */
	RxBufferfullflag = CLEAR;
	MasterRxFlag = CLEAR;
}	
	
/*****************************************************************************/
/* Start of interrupt service routines  */
/* placed into non-banked memory segment as vectors are only 2 bytes */
#pragma CODE_SEG NON_BANKED	
#pragma MESSAGE DISABLE C12056 /* SP debug info */
/******************************************************************************
Function Name	:	_I2CISR
Engineer		:	G.More	
Date			:	31/05/02
Parameters		:	NONE
Returns			:	NONE
Notes			:	Full-function interrupt service routine for I2C module.
******************************************************************************/
#pragma TRAP_PROC
void _I2CISR( void )
{
	volatile tU08 dummyibdrRead;				/* variable to allow dummy reads of IBDR */
	
	Iic.ibsr.bit.ibif = 1;						/* reset the interrupt */
	if(Iic.ibcr.bit.mssl == SET)				/* if module is in master mode */
	{
		if(Iic.ibcr.bit.txrx == SET)			/* if module is to transmit */
		{
			if(TxCompleteflag == SET) 			/* if the last byte has been transmitted */		
			{
				TxCompleteflag = CLEAR;			/* clear the ISR transmit complete flag */
				Iic.ibcr.byte = (IBEN|TXRX);	/* send stop signal (clear MSSL) */
				TxBufferemptyflag = SET;		/* set the non-ISR transmit buffer empty flag */
			}	
			else								/* last byte has not been transmitted */
			{	
				if(Iic.ibsr.bit.rxak == CLEAR)	/* if the slave acknowledged last transfer */
				{
					if(MasterRxFlag == SET)		/* if the last transfer was an address and master is now to Rx */
					{
						Iic.ibcr.bit.txrx = CLEAR; 		/* switch to Rx mode */
						dummyibdrRead = Iic.ibdr.byte;	/* dummy read of IBDR register */
					}
					else						/* last transfer was to instruct other slave to receive */
					{
						Iic.ibdr.byte = *TxPacketpositionptr;		/* write next byte to IBDR */
						if (TxPacketpositionptr == TxPacketendptr)	/* if the last data has been Tx'd */
						{
							TxCompleteflag = SET;	/* set the ISR transmit complete flag */
						}
						else					/* there is still data to be transmitted */
						{
							TxPacketpositionptr++;	/* move to next byte to Tx */
						}
					}
				}
				else							/* slave did not acknowledge last transfer */
				{
					Iic.ibcr.byte = (IBEN|TXRX);	/* send stop signal (clear MSSL) */
				}
			}
		}
		else									/* module is to receive data */
		{				
			if(RxPacketpositionptr == RxPacketendptr)/* if the last byte has been received */
			{
				Iic.ibcr.byte = (IBEN);			/* send stop signal (clear MSSL) */
				RxCompleteflag = SET;			/* set the ISR receive complete flag */
			}
			else								/* last byte has not been received yet */
			{
				if(RxPacketpositionptr == (RxPacketendptr - 1))	/* if the second last byte has been received */
				{
					Iic.ibcr.bit.txak = SET;	/* disable active low acknowledge bit (signal to slave to stop Tx) */
				}
				else							/* second last byte is still to be received */
				{								/* do nothing here */
				}
			}
			
			*RxPacketpositionptr = Iic.ibdr.byte;	/* read the data from the slave */
			
			if (RxCompleteflag == SET)	/* if the last byte of data has been received */
			{
				RxCompleteflag = CLEAR;		/* clear the ISR receive complete flag */
				RxBufferfullflag = SET;		/* set the receive buffer full flag */
			}
			else							/* there is still data to receive */	
			{
				RxPacketpositionptr++;		/* increment the Rx packet position pointer */
			}	
		}
	}						
	else										/* module is in slave mode */
	{
		if(Iic.ibsr.bit.ibal == SET)			/* if module is now in slave mode because arbitration has been lost */
		{
			Iic.ibsr.bit.ibal = 1;				/* reset the abritration flag */
			
			if(Iic.ibsr.bit.iaas == SET)		/* if this module has been addressed as slave */
			{
				if(Iic.ibsr.bit.srw == SET)		/* if module is to transmit */
				{
					Iic.ibcr.bit.txrx = SET; 				/* switch to Tx mode */
					Iic.ibdr.byte = *TxPacketpositionptr;	/* write next byte to IBDR */
					if(TxPacketpositionptr == TxPacketendptr)	/* if the last byte has been transmitted */
					{
						TxBufferemptyflag = SET;	/* raise transmit complete flag */
					}
					else						/* last byte has not been transmitted */
					{
						TxPacketpositionptr++;	/* move to next byte to Tx */
					}
				}
				else							/* module is to receive */
				{
					Iic.ibcr.bit.txrx = CLEAR; 		/* switch to Rx mode */
					dummyibdrRead = Iic.ibdr.byte;	/* dummy read of IBDR register */
				}
			}
			else								/* module has not been addressed as a slave */
			{									/* do nothing here */
			}
		}
		else									/* arbitration was not lost */
		{
			if(Iic.ibsr.bit.iaas == SET)		/* if this module has been addressed as slave */
			{
				if(Iic.ibsr.bit.srw == SET)		/* if module is to transmit */
				{
					Iic.ibcr.bit.txrx = SET; 	/* switch to Tx mode */
					Iic.ibdr.byte = *TxPacketpositionptr;	/* write next byte to IBDR */
					if(TxPacketpositionptr == TxPacketendptr)	/* if the last byte has been transmitted */
					{
						TxBufferemptyflag = SET;	/* raise transmit complete flag */
					}
					else						/* last byte has not been transmitted */
					{
						TxPacketpositionptr++;	/* move to next byte to Tx */
					}		
				}
				else							/* module is to receive */
				{
					Iic.ibcr.bit.txrx = CLEAR; 		/* switch to Rx mode */
					dummyibdrRead = Iic.ibdr.byte;	/* dummy read of IBDR register */
				}
			}
			else								/* module has not been addressed as slave */
			{
				if(Iic.ibcr.bit.txrx == SET)	/* if module is to transmit */
				{
					if(Iic.ibsr.bit.rxak == CLEAR)	/* if the slave acknowledged last transfer */
					{
						Iic.ibdr.byte = *TxPacketpositionptr;	/* write next byte to IBDR */
						if(TxPacketpositionptr == TxPacketendptr)	/* if the last byte has been transmitted */
						{
							TxBufferemptyflag = SET;	/* raise transmit complete flag */
						}
						else					/* last byte has not been transmitted */
						{
							TxPacketpositionptr++;	/* move to next byte to Tx */
						}
					}
					else						/* module is not to transmit */
					{	
						Iic.ibcr.bit.txrx = CLEAR; 	/* switch to Rx mode */
						dummyibdrRead = Iic.ibdr.byte;	/* dummy read of IBDR register */
					}
				}
				else							/* module is to receive data */
				{
					*RxPacketpositionptr = Iic.ibdr.byte;	/* read IBDR register and store in current buffer location */
					if(RxPacketpositionptr == RxPacketendptr)	/* if the last packet has been received */
					{
						RxBufferfullflag = SET;	/* set flag */
					}
					else						/* last packet has yet to be received */
					{
						RxPacketpositionptr++;	/* move to next byte to transmit */
					}
				}					
			}
		}
	}			
}
					
/******************************************************************************
Function Name	:	_dummyISR
Engineer		:	M.Gallop	
Date			:	25/07/01
Parameters		:	NONE
Returns			:	NONE
Notes			:	Interrupt service routine for unused interrupt vectors. 
******************************************************************************/
#pragma TRAP_PROC
void 
_dummyISR( void )
{				
   for(;;); 	/* endless cycle */                               
}

/* End of interrupt service routines  */
/* reset code segment to default */
#pragma CODE_SEG DEFAULT
